 
package pl.malinowski.sharedViews.processors;

import java.util.List;
import java.util.Vector;

import javax.inject.Inject;
import javax.inject.Named;

import org.eclipse.e4.core.di.annotations.Execute;
import org.eclipse.e4.ui.model.application.commands.MCommand;
import org.eclipse.e4.ui.model.application.commands.MCommandParameter;
import org.eclipse.e4.ui.model.application.commands.MCommandsFactory;
import org.eclipse.e4.ui.model.application.commands.MParameter;
import org.eclipse.e4.ui.model.application.ui.advanced.MPerspective;
import org.eclipse.e4.ui.model.application.ui.advanced.MPerspectiveStack;
import org.eclipse.e4.ui.model.application.ui.menu.ItemType;
import org.eclipse.e4.ui.model.application.ui.menu.MHandledToolItem;
import org.eclipse.e4.ui.model.application.ui.menu.MMenuFactory;
import org.eclipse.e4.ui.model.application.ui.menu.MToolBar;

public class MainProcessor 
{
	@Inject @Named("pl.malinowski.sharedviews.perspectivestack")
	private MPerspectiveStack perspectiveStack;
	
	@Inject @Named("pl.malinowski.sharedviews.command.perspectives")
	private MCommand perspectiveCommand;
	
	@Inject @Named("pl.malinowski.sharedviews.toolbar.perspectives")
	private MToolBar toolBar;
	
	private List<MPerspective> toBeDeleted = new Vector<MPerspective>();
	
	@Execute
	public void execute() 
	{		
		MCommandParameter commandParameter = perspectiveCommand.getParameters().get(0);
		
		for (MPerspective perspective : perspectiveStack.getChildren())
		{
			int code = isAlreadeMerged(perspective);
			
			switch (code)
			{
				case 1:
					// leave it, this perspective is fine
					break;
				case 0:
					// duplicated perspective from fragment, remove it later
					toBeDeleted.add(perspective);
					break;
				case -1:
					// new perspective
					perspective.setElementId(perspective.getElementId() + ".merged");
					
					MParameter parameter = MCommandsFactory.INSTANCE.createParameter();
					parameter.setElementId("perspective.id");
					parameter.setName(commandParameter.getElementId());
					parameter.setValue(perspective.getElementId());
					
					MHandledToolItem toolItem = MMenuFactory.INSTANCE.createHandledToolItem();
					toolItem.setType(ItemType.RADIO);
					toolItem.setSelected(false);
					toolItem.setLabel(perspective.getLabel());
					toolItem.setTooltip("Switch to " + perspective.getLabel() + " perspective.");
					toolItem.setElementId(toolBar.getElementId() + perspective.getLabel().toLowerCase());
					toolItem.getParameters().add(parameter);
					toolItem.setCommand(perspectiveCommand);
					
					toolBar.getChildren().add(toolItem);
					break;
				default:
					break;
			}
			System.out.println();
		}
		
		for (MPerspective perspective : toBeDeleted)
		{
			perspectiveStack.getChildren().remove(perspective);
		}
	}
	
	private int isAlreadeMerged(MPerspective perspective)
	{
		if (perspective.getElementId().contains("merged"))
			return 1;
		for (MPerspective pers : perspectiveStack.getChildren())
		{
			if (pers.getElementId().equals(perspective.getElementId() + ".merged"))
				return 0;
		}
		return -1;
	}
}